@@ -931,11 +931,11 @@ void Logging::UseFile()
         QDir dir;
         QString path =
             QDir(KSPaths::writableLocation(QStandardPaths::AppLocalDataLocation))
-            .filePath("logs/" + QDateTime::currentDateTime().toString("yyyy-MM-dd"));
+                .filePath("logs" + QDir::separator() + QDateTime::currentDateTime().toString("yyyy-MM-dd"));
         dir.mkpath(path);
         QString name =
             "log_" + QDateTime::currentDateTime().toString("HH-mm-ss") + ".txt";
-        _filename = path + QStringLiteral("/") + name;
+        _filename = path + QDir::separator() + name;
 
         // Clear file contents
         QFile file(_filename);
@@ -1120,7 +1120,7 @@ QString getDefaultPath(const QString &option)
 
     if (option == "fitsDir")
     {
-        return QDir::homePath();
+        return QDir::toNativeSeparators(QDir::homePath());
     }
     else if (option == "indiServer")
     {
@@ -1131,6 +1131,14 @@ QString getDefaultPath(const QString &option)
 #endif
         return prefix + "/bin/indiserver";
     }
+    else if (option == "PlaceholderFormat")
+    {
+#if defined(Q_OS_WIN)
+        return "\\%t\\%T\\%F\\%t_%T_%F";
+#else
+        return "/%t/%T/%F/%t_%T_%F";
+#endif
+    }
     else if (option == "INDIHubAgent")
     {
 #if defined(INDI_PREFIX)
@@ -1744,13 +1752,8 @@ JPLParser::JPLParser(const QString &path)
     }
 
     const auto &ast_json = QJsonDocument::fromJson(jpl_file.readAll());
-#if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
     const auto &fields   = ast_json["fields"].toArray();
     m_data               = ast_json["data"].toArray();
-#else
-    const auto &fields   = ast_json.object().value("fields").toArray();
-    m_data               = ast_json.object().value("data").toArray();
-#endif
 
     {
         int i = 0;
@@ -1794,4 +1797,23 @@ MPCParser::MPCParser(const QString &path)
         qCritical(KSTARS) << "Failed to read MPC comets data file" << path;
 }
 
+void setGlobalSettings(const QVariantMap &settings)
+{
+    for (auto &key : settings.keys())
+    {
+        auto property = key;
+        // Anything starting with kcfg_ must be processed to remove the
+        // prefix and ensure first letter is lower case.
+        if (property.startsWith("kcfg_"))
+        {
+            property.remove("kcfg_");
+            property.replace(0, 1, property.at(0).toLower());
+        }
+        Options::self()->setProperty(property.toLatin1(), settings[key]);
+    }
+
+    Options::self()->save();
+}
+
+
 } // namespace KSUtils
