@@ -10,12 +10,10 @@
 #include "align.h"
 #include "kstars.h"
 #include "kstarsdata.h"
-#include "ksnotification.h"
 #include "ksmessagebox.h"
 #include "ekos/auxiliary/stellarsolverprofile.h"
 #include "ekos/auxiliary/solverutils.h"
 #include "Options.h"
-#include "QProgressIndicator.h"
 #include "polaralignwidget.h"
 #include <ekos_align_debug.h>
 
@@ -24,7 +22,7 @@
 namespace Ekos
 {
 
-const QMap<PolarAlignmentAssistant::PAHStage, const char *> PolarAlignmentAssistant::PAHStages =
+const QMap<PolarAlignmentAssistant::Stage, const char *> PolarAlignmentAssistant::PAHStages =
 {
     {PAH_IDLE, I18N_NOOP("Idle")},
     {PAH_FIRST_CAPTURE, I18N_NOOP("First Capture")},
@@ -52,18 +50,12 @@ PolarAlignmentAssistant::PolarAlignmentAssistant(Align *parent, const QSharedPoi
     m_AlignInstance = parent;
     m_AlignView = view;
 
-    connect(PAHSlewRateCombo, static_cast<void (QComboBox::*)(int)>(&QComboBox::activated), [&](int index)
-    {
-        Options::setPAHMountSpeedIndex(index);
-    });
+    showUpdatedError((pAHRefreshAlgorithm->currentIndex() == PLATE_SOLVE_ALGORITHM) ||
+                     (pAHRefreshAlgorithm->currentIndex() == MOVE_STAR_UPDATE_ERR_ALGORITHM));
 
-    showUpdatedError((Options::pAHRefreshAlgorithm() == PLATE_SOLVE_ALGORITHM) ||
-                     (Options::pAHRefreshAlgorithm() == MOVE_STAR_UPDATE_ERR_ALGORITHM));
-
-    PAHRefreshAlgorithmCombo->setCurrentIndex(Options::pAHRefreshAlgorithm());
-    connect(PAHRefreshAlgorithmCombo, static_cast<void (QComboBox::*)(int)>(&QComboBox::activated), this, [this](int index)
+    connect(pAHRefreshAlgorithm, QOverload<int>::of(&QComboBox::currentIndexChanged), this, [this](int index)
     {
-        setPAHRefreshAlgorithm(static_cast<PAHRefreshAlgorithm>(index));
+        setPAHRefreshAlgorithm(static_cast<RefreshAlgorithm>(index));
     });
     starCorrespondencePAH.reset();
 
@@ -73,10 +65,10 @@ PolarAlignmentAssistant::PolarAlignmentAssistant(Align *parent, const QSharedPoi
     {
         PAHStartB->setEnabled(enabled);
         directionLabel->setEnabled(enabled);
-        PAHDirectionCombo->setEnabled(enabled);
-        PAHRotationSpin->setEnabled(enabled);
-        PAHSlewRateCombo->setEnabled(enabled);
-        PAHManual->setEnabled(enabled);
+        pAHDirection->setEnabled(enabled);
+        pAHRotation->setEnabled(enabled);
+        pAHMountSpeed->setEnabled(enabled);
+        pAHManualSlew->setEnabled(enabled);
     });
     connect(PAHStartB, &QPushButton::clicked, this, &Ekos::PolarAlignmentAssistant::startPAHProcess);
     // PAH StopB is just a shortcut for the regular stop
@@ -105,24 +97,13 @@ void PolarAlignmentAssistant::showUpdatedError(bool show)
     PAHUpdatedErrorAz->setVisible(show);
 }
 
-void PolarAlignmentAssistant::syncMountSpeed()
+void PolarAlignmentAssistant::syncMountSpeed(const QString &speed)
 {
-    PAHSlewRateCombo->blockSignals(true);
-    PAHSlewRateCombo->clear();
-    PAHSlewRateCombo->addItems(m_CurrentTelescope->slewRates());
-    const uint16_t configMountSpeed = Options::pAHMountSpeedIndex();
-    if (configMountSpeed < PAHSlewRateCombo->count())
-        PAHSlewRateCombo->setCurrentIndex(configMountSpeed);
-    else
-    {
-        int currentSlewRateIndex = m_CurrentTelescope->getSlewRate();
-        if (currentSlewRateIndex >= 0)
-        {
-            PAHSlewRateCombo->setCurrentIndex(currentSlewRateIndex);
-            Options::setPAHMountSpeedIndex(currentSlewRateIndex);
-        }
-    }
-    PAHSlewRateCombo->blockSignals(false);
+    pAHMountSpeed->blockSignals(true);
+    pAHMountSpeed->clear();
+    pAHMountSpeed->addItems(m_CurrentTelescope->slewRates());
+    pAHMountSpeed->setCurrentText(speed);
+    pAHMountSpeed->blockSignals(false);
 }
 
 void PolarAlignmentAssistant::setEnabled(bool enabled)
@@ -137,9 +118,7 @@ void PolarAlignmentAssistant::setEnabled(bool enabled)
     }
     else
     {
-        PAHWidgets->setToolTip(i18n(
-                                   "<p>Polar Alignment Helper tool requires the following:</p><p>1. German Equatorial Mount</p><p>2. FOV &gt;"
-                                   " 0.5 degrees</p><p>For small FOVs, use the Legacy Polar Alignment Tool.</p>"));
+        PAHWidgets->setToolTip(i18n("<p>Polar Alignment tool requires a German Equatorial Mount.</p>"));
         FOVDisabledLabel->show();
     }
 
@@ -200,6 +179,7 @@ void PolarAlignmentAssistant::solverDone(bool timedOut, bool success, const FITS
     else if (!success)
     {
         emit newLog(i18n("Refresh solver failed: %1s", QString("%L1").arg(elapsedSeconds, 0, 'f', 1)));
+        emit updatedErrorsChanged(-1, -1, -1);
         emit captureAndSolve();
     }
     else
@@ -441,7 +421,7 @@ void PolarAlignmentAssistant::processPAHRefresh()
     imageNumber++;
     PAHIteration->setText(QString("Image %1").arg(imageNumber));
 
-    if (Options::pAHRefreshAlgorithm() == PLATE_SOLVE_ALGORITHM)
+    if (pAHRefreshAlgorithm->currentIndex() == PLATE_SOLVE_ALGORITHM)
     {
         startSolver();
         return;
@@ -451,7 +431,7 @@ void PolarAlignmentAssistant::processPAHRefresh()
     // so that if it is enabled later the star could be tracked.
     // Flaw here is that if enough stars are not detected, iteration is not incremented,
     // so it may repeat.
-    if ((Options::pAHRefreshAlgorithm() == MOVE_STAR_UPDATE_ERR_ALGORITHM) || (refreshIteration == 0))
+    if ((pAHRefreshAlgorithm->currentIndex() == MOVE_STAR_UPDATE_ERR_ALGORITHM) || (refreshIteration == 0))
     {
         constexpr int MIN_PAH_REFRESH_STARS = 10;
 
@@ -568,6 +548,7 @@ void PolarAlignmentAssistant::processPAHRefresh()
         {
             debugString = QString("PAA Refresh(%1): Too few stars detected (%2)").arg(refreshIteration).arg(stars.size());
             qCDebug(KSTARS_EKOS_ALIGN) << debugString;
+            emit updatedErrorsChanged(-1, -1, -1);
         }
     }
     // Finally start the next capture
@@ -597,7 +578,7 @@ bool PolarAlignmentAssistant::processSolverFailure()
     return false;
 }
 
-void PolarAlignmentAssistant::setPAHStage(PAHStage stage)
+void PolarAlignmentAssistant::setPAHStage(Stage stage)
 {
     if (stage != m_PAHStage)
     {
@@ -613,8 +594,8 @@ void PolarAlignmentAssistant::processMountRotation(const dms &ra, double settleD
 
     QString rotProgressMessage;
     QString rotDoneMessage;
-    PAHStage nextCapture;
-    PAHStage nextSettle;
+    Stage nextCapture;
+    Stage nextSettle;
 
     if (m_PAHStage == PAH_FIRST_ROTATE)
     {
@@ -635,7 +616,7 @@ void PolarAlignmentAssistant::processMountRotation(const dms &ra, double settleD
     if (m_PAHStage == PAH_FIRST_ROTATE || m_PAHStage == PAH_SECOND_ROTATE)
     {
         // only wait for telescope to slew to new position if manual slewing is switched off
-        if(!PAHManual->isChecked())
+        if(!pAHManualSlew->isChecked())
         {
             qCDebug(KSTARS_EKOS_ALIGN) << rotProgressMessage << deltaAngle;
             if (deltaAngle <= PAH_ROTATION_THRESHOLD)
@@ -662,9 +643,9 @@ void PolarAlignmentAssistant::processMountRotation(const dms &ra, double settleD
                 }
             }
             // If for some reason we didn't stop, let's stop if we get too far
-            else if (deltaAngle > PAHRotationSpin->value() * 1.25)
+            else if (deltaAngle > pAHRotation->value() * 1.25)
             {
-                m_CurrentTelescope->Abort();
+                m_CurrentTelescope->abort();
                 emit newLog(i18n("Mount aborted. Reverse RA axis direction and try again."));
                 stopPAHProcess();
             }
@@ -693,28 +674,28 @@ bool PolarAlignmentAssistant::checkPAHForMeridianCrossing()
     if (nearThePole)
         return false;
 
-    double degreesPerSlew = PAHRotationSpin->value();
+    double degreesPerSlew = pAHRotation->value();
     bool closeToMeridian = fabs(hourAngle) < 2.0 * degreesPerSlew;
-    bool goingWest = PAHDirectionCombo->currentIndex() == 0;
+    bool goingWest = pAHDirection->currentIndex() == 0;
 
     // If the pier is on the east side (pointing west) and will slew west and is within 2 slews of the HA=0,
     // or on the west side (pointing east) and will slew east, and is within 2 slews of HA=0
     // then warn and give the user a chance to cancel.
     bool wouldCrossMeridian =
-        ((m_CurrentTelescope->pierSide() == ISD::Telescope::PIER_EAST && !goingWest && closeToMeridian) ||
-         (m_CurrentTelescope->pierSide() == ISD::Telescope::PIER_WEST && goingWest && closeToMeridian) ||
-         (m_CurrentTelescope->pierSide() == ISD::Telescope::PIER_UNKNOWN && closeToMeridian));
+        ((m_CurrentTelescope->pierSide() == ISD::Mount::PIER_EAST && !goingWest && closeToMeridian) ||
+         (m_CurrentTelescope->pierSide() == ISD::Mount::PIER_WEST && goingWest && closeToMeridian) ||
+         (m_CurrentTelescope->pierSide() == ISD::Mount::PIER_UNKNOWN && closeToMeridian));
 
     return wouldCrossMeridian;
 }
 
-void PolarAlignmentAssistant::updateDisplay(PAHStage stage, const QString &message)
+void PolarAlignmentAssistant::updateDisplay(Stage stage, const QString &message)
 {
     switch(stage)
     {
         case PAH_FIRST_ROTATE:
         case PAH_SECOND_ROTATE:
-            if (PAHManual->isChecked())
+            if (pAHManualSlew->isChecked())
             {
                 polarAlignWidget->updatePAHStage(stage);
                 PAHWidgets->setCurrentWidget(PAHManualRotatePage);
@@ -759,7 +740,7 @@ void PolarAlignmentAssistant::startPAHProcess()
         }
 
         // Unpark
-        m_CurrentTelescope->UnPark();
+        m_CurrentTelescope->unpark();
 
         // Set tracking ON if not already
         if (m_CurrentTelescope->canControlTrack() && m_CurrentTelescope->isTracking() == false)
@@ -821,7 +802,7 @@ void PolarAlignmentAssistant::stopPAHProcess()
         return;
 
     if (m_CurrentTelescope && m_CurrentTelescope->isInMotion())
-        m_CurrentTelescope->Abort();
+        m_CurrentTelescope->abort();
 
     setPAHStage(PAH_IDLE);
     polarAlignWidget->updatePAHStage(m_PAHStage);
@@ -836,20 +817,21 @@ void PolarAlignmentAssistant::stopPAHProcess()
     m_AlignView->setRefreshEnabled(false);
 
     emit newFrame(m_AlignView);
-    disconnect(m_AlignView.get(), &AlignView::trackingStarSelected, this, &Ekos::PolarAlignmentAssistant::setPAHCorrectionOffset);
+    disconnect(m_AlignView.get(), &AlignView::trackingStarSelected, this,
+               &Ekos::PolarAlignmentAssistant::setPAHCorrectionOffset);
     disconnect(m_AlignView.get(), &AlignView::newCorrectionVector, this, &Ekos::PolarAlignmentAssistant::newCorrectionVector);
 
     if (Options::pAHAutoPark())
     {
-        m_CurrentTelescope->Park();
+        m_CurrentTelescope->park();
         emit newLog(i18n("Parking the mount..."));
     }
 }
 
 void PolarAlignmentAssistant::rotatePAH()
 {
-    double TargetDiffRA = PAHRotationSpin->value();
-    bool westMeridian = PAHDirectionCombo->currentIndex() == 0;
+    double TargetDiffRA = pAHRotation->value();
+    bool westMeridian = pAHDirection->currentIndex() == 0;
 
     // West
     if (westMeridian)
@@ -861,7 +843,7 @@ void PolarAlignmentAssistant::rotatePAH()
     // JM 2018-05-03: Hemispheres shouldn't affect rotation direction in RA
 
     // if Manual slewing is selected, don't move the mount
-    if (PAHManual->isChecked())
+    if (pAHManualSlew->isChecked())
     {
         return;
     }
@@ -876,11 +858,11 @@ void PolarAlignmentAssistant::rotatePAH()
 
     //m_CurrentTelescope->Slew(&targetPAH);
     // Set Selected Speed
-    if (PAHSlewRateCombo->currentIndex() >= 0)
-        m_CurrentTelescope->setSlewRate(PAHSlewRateCombo->currentIndex());
+    if (pAHMountSpeed->currentIndex() >= 0)
+        m_CurrentTelescope->setSlewRate(pAHMountSpeed->currentIndex());
     // Go to direction
-    m_CurrentTelescope->MoveWE(westMeridian ? ISD::Telescope::MOTION_WEST : ISD::Telescope::MOTION_EAST,
-                               ISD::Telescope::MOTION_START);
+    m_CurrentTelescope->MoveWE(westMeridian ? ISD::Mount::MOTION_WEST : ISD::Mount::MOTION_EAST,
+                               ISD::Mount::MOTION_START);
 
     emit newLog(i18n("Please wait until mount completes rotating to RA (%1) DE (%2)", targetPAH.ra().toHMSString(),
                      targetPAH.dec().toDMSString()));
@@ -914,7 +896,7 @@ void PolarAlignmentAssistant::setupCorrectionGraphics(const QPointF &pixel)
     qCDebug(KSTARS_EKOS_ALIGN) << debugString;
     correctionFrom = pixel;
 
-    if (Options::pAHRefreshAlgorithm() == PLATE_SOLVE_ALGORITHM)
+    if (pAHRefreshAlgorithm->currentIndex() == PLATE_SOLVE_ALGORITHM)
         updatePlateSolveTriangle(imageData);
     else
         m_AlignView->setCorrectionParams(correctionFrom, correctionTo, correctionAltTo);
@@ -941,8 +923,9 @@ bool PolarAlignmentAssistant::calculatePAHError()
     dms polarError(hypot(altitudeError, azimuthError));
     dms azError(azimuthError), altError(altitudeError);
 
-    if (m_AlignView->isEQGridShown() == false && !Options::limitedResourcesMode())
-        m_AlignView->toggleEQGrid();
+    // No need to toggle EQGrid
+    //    if (m_AlignView->isEQGridShown() == false && !Options::limitedResourcesMode())
+    //        m_AlignView->toggleEQGrid();
 
     QString msg = QString("%1. Azimuth: %2  Altitude: %3")
                   .arg(polarError.toDMSString()).arg(azError.toDMSString())
@@ -983,7 +966,7 @@ bool PolarAlignmentAssistant::calculatePAHError()
 
 void PolarAlignmentAssistant::syncCorrectionVector()
 {
-    if (Options::pAHRefreshAlgorithm() == PLATE_SOLVE_ALGORITHM)
+    if (pAHRefreshAlgorithm->currentIndex() == PLATE_SOLVE_ALGORITHM)
         return;
     emit newCorrectionVector(QLineF(correctionFrom, correctionTo));
     m_AlignView->setCorrectionParams(correctionFrom, correctionTo, correctionAltTo);
@@ -1038,8 +1021,6 @@ void PolarAlignmentAssistant::startPAHRefreshProcess()
 
     refreshIteration = 0;
     imageNumber = 0;
-    m_IndexToUse = -1;
-    m_HealpixToUse = -1;
     m_NumHealpixFailures = 0;
 
     setPAHStage(PAH_REFRESH);
@@ -1062,7 +1043,7 @@ void PolarAlignmentAssistant::startPAHRefreshProcess()
 }
 
 void PolarAlignmentAssistant::processPAHStage(double orientation, double ra, double dec, double pixscale,
-        bool eastToTheRight)
+        bool eastToTheRight, short healpix, short index)
 {
     if (m_PAHStage == PAH_FIND_CP)
     {
@@ -1075,11 +1056,13 @@ void PolarAlignmentAssistant::processPAHStage(double orientation, double ra, dou
 
     if (m_PAHStage == PAH_FIRST_SOLVE || m_PAHStage == PAH_SECOND_SOLVE || m_PAHStage == PAH_THIRD_SOLVE)
     {
-        // For now just used by refresh, when looking at the 3rd image.
+        // Used by refresh, when looking at the 3rd image.
         m_LastRa = ra;
         m_LastDec = dec;
         m_LastOrientation = orientation;
         m_LastPixscale = pixscale;
+        m_HealpixToUse = healpix;
+        m_IndexToUse = index;
 
         bool doWcs = (m_PAHStage == PAH_THIRD_SOLVE) || !Options::limitedResourcesMode();
         if (doWcs)
@@ -1091,35 +1074,13 @@ void PolarAlignmentAssistant::processPAHStage(double orientation, double ra, dou
                 : (m_PAHStage == PAH_SECOND_SOLVE ? "Calculating WCS for the second image...</p>"
                    : "Calculating WCS for the third image...</p>"));
         }
-        connect(m_AlignView.get(), &AlignView::wcsToggled, this, &Ekos::PolarAlignmentAssistant::setWCSToggled, Qt::UniqueConnection);
+        connect(m_AlignView.get(), &AlignView::wcsToggled, this, &Ekos::PolarAlignmentAssistant::setWCSToggled,
+                Qt::UniqueConnection);
         m_AlignView->injectWCS(orientation, ra, dec, pixscale, eastToTheRight, doWcs);
         return;
     }
 }
 
-QJsonObject PolarAlignmentAssistant::getPAHSettings() const
-{
-    QJsonObject settings;
-
-    settings.insert("mountDirection", PAHDirectionCombo->currentIndex());
-    settings.insert("mountSpeed", PAHSlewRateCombo->currentIndex());
-    settings.insert("mountRotation", PAHRotationSpin->value());
-    settings.insert("refresh", PAHExposure->value());
-    settings.insert("manualslew", PAHManual->isChecked());
-
-    return settings;
-}
-
-void PolarAlignmentAssistant::setPAHSettings(const QJsonObject &settings)
-{
-    PAHDirectionCombo->setCurrentIndex(settings["mountDirection"].toInt(0));
-    PAHRotationSpin->setValue(settings["mountRotation"].toInt(30));
-    PAHExposure->setValue(settings["refresh"].toDouble(2));
-    if (settings.contains("mountSpeed"))
-        PAHSlewRateCombo->setCurrentIndex(settings["mountSpeed"].toInt(0));
-    PAHManual->setChecked(settings["manualslew"].toBool(false));
-}
-
 void PolarAlignmentAssistant::setImageData(const QSharedPointer<FITSData> &image)
 {
     m_ImageData = image;
@@ -1156,10 +1117,10 @@ void PolarAlignmentAssistant::setWCSToggled(bool result)
 
         setPAHStage(PAH_FIRST_ROTATE);
         auto msg = getPAHMessage();
-        if (PAHManual->isChecked())
+        if (pAHManualSlew->isChecked())
         {
             msg = QString("Please rotate your mount about %1 deg in RA")
-                  .arg(PAHRotationSpin->value());
+                  .arg(pAHRotation->value());
             emit newLog(msg);
         }
         updateDisplay(m_PAHStage, msg);
@@ -1171,10 +1132,10 @@ void PolarAlignmentAssistant::setWCSToggled(bool result)
         setPAHStage(PAH_SECOND_ROTATE);
         auto msg = getPAHMessage();
 
-        if (PAHManual->isChecked())
+        if (pAHManualSlew->isChecked())
         {
             msg = QString("Please rotate your mount about %1 deg in RA")
-                  .arg(PAHRotationSpin->value());
+                  .arg(pAHRotation->value());
             emit newLog(msg);
         }
         updateDisplay(m_PAHStage, msg);
@@ -1212,13 +1173,13 @@ void PolarAlignmentAssistant::setWCSToggled(bool result)
     }
 }
 
-void PolarAlignmentAssistant::setMountStatus(ISD::Telescope::Status newState)
+void PolarAlignmentAssistant::setMountStatus(ISD::Mount::Status newState)
 {
     switch (newState)
     {
-        case ISD::Telescope::MOUNT_PARKING:
-        case ISD::Telescope::MOUNT_SLEWING:
-        case ISD::Telescope::MOUNT_MOVING:
+        case ISD::Mount::MOUNT_PARKING:
+        case ISD::Mount::MOUNT_SLEWING:
+        case ISD::Mount::MOUNT_MOVING:
             PAHStartB->setEnabled(false);
             break;
 
@@ -1257,12 +1218,12 @@ QString PolarAlignmentAssistant::getPAHMessage() const
         case PAH_THIRD_SOLVE:
             return "<p>Solving the <i>third</i> image...</p>";
         case PAH_STAR_SELECT:
-            if (Options::pAHRefreshAlgorithm() == PLATE_SOLVE_ALGORITHM)
+            if (pAHRefreshAlgorithm->currentIndex() == PLATE_SOLVE_ALGORITHM)
                 return "<p>Choose your exposure time & select an adjustment method. Then click <i>refresh</i> to begin adjustments.</p>";
             else
                 return "<p>Choose your exposure time & select an adjustment method. Click <i>Refresh</i> to begin.</p><p>Correction triangle is plotted above. <i>Zoom in and select a bright star</i> to reposition the correction vector. Use the <i>MoveStar & Calc Error</i> method to estimate the remaining error.</p>";
         case PAH_REFRESH:
-            if (Options::pAHRefreshAlgorithm() == PLATE_SOLVE_ALGORITHM)
+            if (pAHRefreshAlgorithm->currentIndex() == PLATE_SOLVE_ALGORITHM)
                 return "<p>Adjust mount's <i>Altitude and Azimuth knobs</i> to reduce the polar alignment error.</p><p>Be patient, plate solving can be affected by knob movement. Consider using results after 2 images.  Click <i>Stop</i> when the you're finished.</p>";
             else
                 return "<p>Adjust mount's <i>Altitude knob</i> to move the star along the yellow line, then adjust the <i>Azimuth knob</i> to move it along the Green line until the selected star is centered within the crosshair.</p><p>Click <i>Stop</i> when the star is centered.</p>";
@@ -1273,27 +1234,26 @@ QString PolarAlignmentAssistant::getPAHMessage() const
     return QString();
 }
 
-void PolarAlignmentAssistant::setPAHRefreshAlgorithm(PAHRefreshAlgorithm value)
+void PolarAlignmentAssistant::setPAHRefreshAlgorithm(RefreshAlgorithm value)
 {
     // If the star-correspondence method of tracking polar alignment error wasn't initialized,
     // at the start, it can't be turned on mid process.
     if ((m_PAHStage == PAH_REFRESH) && refreshIteration > 0 && (value != PLATE_SOLVE_ALGORITHM)
             && !starCorrespondencePAH.size())
     {
-        PAHRefreshAlgorithmCombo->setCurrentIndex(PLATE_SOLVE_ALGORITHM);
-        Options::setPAHRefreshAlgorithm(PLATE_SOLVE_ALGORITHM);
+        pAHRefreshAlgorithm->setCurrentIndex(PLATE_SOLVE_ALGORITHM);
         emit newLog(i18n("Cannot change to MoveStar algorithm once refresh has begun"));
         return;
     }
-    Options::setPAHRefreshAlgorithm(value);
     if (m_PAHStage == PAH_REFRESH || m_PAHStage == PAH_STAR_SELECT)
     {
         refreshText->setText(getPAHMessage());
         emit newPAHMessage(getPAHMessage());
     }
-    showUpdatedError((Options::pAHRefreshAlgorithm() == PLATE_SOLVE_ALGORITHM) ||
-                     (Options::pAHRefreshAlgorithm() == MOVE_STAR_UPDATE_ERR_ALGORITHM));
-    if (Options::pAHRefreshAlgorithm() == PLATE_SOLVE_ALGORITHM)
+
+    showUpdatedError((value == PLATE_SOLVE_ALGORITHM) ||
+                     (value == MOVE_STAR_UPDATE_ERR_ALGORITHM));
+    if (value == PLATE_SOLVE_ALGORITHM)
         updatePlateSolveTriangle(m_ImageData);
     else
         m_AlignView->setCorrectionParams(correctionFrom, correctionTo, correctionAltTo);
