@@ -6,8 +6,8 @@
 
 #pragma once
 
-#include "indi/indiccd.h"
-#include "indi/indicap.h"
+#include "indi/indicamera.h"
+#include "indi/indidustcap.h"
 #include "darkview.h"
 #include "defectmap.h"
 #include "ekos/ekos.h"
@@ -63,7 +63,7 @@ class DarkLibrary : public QDialog, public Ui::DarkLibrary
          * @param darkData If a frame is found, load it from disk and store it in a shared FITSData pointer.
          * @return True if a suitable frame was found the loaded successfully, false otherwise.
          */
-        bool findDarkFrame(ISD::CCDChip *targetChip, double duration, QSharedPointer<FITSData> &darkData);
+        bool findDarkFrame(ISD::CameraChip *targetChip, double duration, QSharedPointer<FITSData> &darkData);
 
         /**
          * @brief findDefectMap Search for a defect map that matches the passed paramters.
@@ -72,37 +72,43 @@ class DarkLibrary : public QDialog, public Ui::DarkLibrary
          * @param defectMap If a frame is found, load it from disk and store it in a shared DefectMap pointer.
          * @return True if a suitable frame was found the loaded successfully, false otherwise.
          */
-        bool findDefectMap(ISD::CCDChip *targetChip, double duration, QSharedPointer<DefectMap> &defectMap);
-
-        /**
-         * @brief cameraHasDefectMaps Check if camera has any defect maps available.
-         * @param name Camera name
-         * @return True if at least one defect maps exists for this camera, false otherwise.
-         */
-        bool cameraHasDefectMaps(const QString &name) const
-        {
-            return m_DefectCameras.contains(name);
-        }
+        bool findDefectMap(ISD::CameraChip *targetChip, double duration, QSharedPointer<DefectMap> &defectMap);        
 
         void refreshFromDB();
-        void addCamera(ISD::GDInterface * newCCD);
-        void removeCamera(ISD::GDInterface * newCCD);
-        void checkCamera(int ccdNum = -1);
+        bool setCamera(ISD::Camera *device);
+        void removeDevice(const QSharedPointer<ISD::GenericDevice> &device);
+        void checkCamera();
         //void reset();
         void setCaptureModule(Capture *instance);
 
         void start();
-        void setDarkSettings(const QJsonObject &settings);
         void setCameraPresets(const QJsonObject &settings);
-        QJsonObject getCameraPresets();
-        QJsonObject getDarkSettings();
-        QJsonObject getDefectSettings();
+        QJsonObject getCameraPresets();        
         void setDefectPixels(const QJsonObject &payload);
         QJsonArray getViewMasters();
         void getloadDarkViewMasterFITS(int index);
-        void setDefectSettings(const QJsonObject row);
+
+        /**
+         * @brief getDefectSettings Return Defect Map settings
+         * @return JSON Object of defect map settings
+         */
+        QJsonObject getDefectSettings();
+
         void setDefectMapEnabled(bool enabled);
 
+        // Settings
+        QVariantMap getAllSettings() const;
+        void setAllSettings(const QVariantMap &settings);
+
+        QString opticalTrain() const
+        {
+            return opticalTrainCombo->currentText();
+        }
+        void setOpticalTrain(const QString &value)
+        {
+            opticalTrainCombo->setCurrentText(value);
+        }
+
         /**
          * @brief stop Abort all dark job captures.
          */
@@ -114,10 +120,13 @@ class DarkLibrary : public QDialog, public Ui::DarkLibrary
         void newLog(const QString &message);
         void newImage(const QSharedPointer<FITSData> &data);
         void newFrame(const QSharedPointer<FITSView> &view);
+        // Settings
+        void settingsUpdated(const QVariantMap &settings);
+        void trainChanged();
 
     public slots:
         void processNewImage(SequenceJob *job, const QSharedPointer<FITSData> &data);
-        void processNewBLOB(IBLOB *bp);
+        void updateProperty(INDI::Property prop);
         void loadIndexInView(int row);
         void clearRow(int row = -1);
 
@@ -207,6 +216,12 @@ class DarkLibrary : public QDialog, public Ui::DarkLibrary
         ////////////////////////////////////////////////////////////////////////////////////////////////
         double getGain();
 
+        ////////////////////////////////////////////////////////////////////////////////////////////////
+        /// Optical Train
+        ////////////////////////////////////////////////////////////////////////////////////////////////
+        void setupOpticalTrainManager();
+        void refreshOpticalTrain();
+
         ////////////////////////////////////////////////////////////////////////////////////////////////
         /// Defect Map Functions
         ////////////////////////////////////////////////////////////////////////////////////////////////
@@ -221,6 +236,38 @@ class DarkLibrary : public QDialog, public Ui::DarkLibrary
          */
         bool cacheDefectMapFromFile(const QString &key, const QString &filename);
 
+        ////////////////////////////////////////////////////////////////////
+        /// Settings
+        ////////////////////////////////////////////////////////////////////
+
+        /**
+         * @brief Connect GUI elements to sync settings once updated.
+         */
+        void connectSettings();
+        /**
+         * @brief Stop updating settings when GUI elements are updated.
+         */
+        void disconnectSettings();
+        /**
+         * @brief loadSettings Load setting from Options and set them accordingly.
+         */
+        void loadGlobalSettings();
+
+        /**
+         * @brief syncSettings When checkboxes, comboboxes, or spin boxes are updated, save their values in the
+         * global and per-train settings.
+         */
+        void syncSettings();
+
+        /**
+         * @brief syncControl Sync setting to widget. The value depends on the widget type.
+         * @param settings Map of all settings
+         * @param key name of widget to sync
+         * @param widget pointer of widget to set
+         * @return True if sync successful, false otherwise
+         */
+        bool syncControl(const QVariantMap &settings, const QString &key, QWidget * widget);
+
         ////////////////////////////////////////////////////////////////////////////////////////////////
         /// Member Variables
         ////////////////////////////////////////////////////////////////////////////////////////////////
@@ -229,9 +276,8 @@ class DarkLibrary : public QDialog, public Ui::DarkLibrary
         QMap<QString, QSharedPointer<FITSData>> m_CachedDarkFrames;
         QMap<QString, QSharedPointer<DefectMap>> m_CachedDefectMaps;
 
-        ISD::CCD *m_CurrentCamera {nullptr};
-        ISD::CCDChip *m_TargetChip {nullptr};
-        QList<ISD::CCD *> m_Cameras;
+        ISD::Camera *m_Camera {nullptr};
+        ISD::CameraChip *m_TargetChip {nullptr};
         bool m_UseGuideHead {false};
         double GainSpinSpecialValue { INVALID_VALUE };
 
@@ -245,8 +291,7 @@ class DarkLibrary : public QDialog, public Ui::DarkLibrary
         bool m_RememberSummaryView {true};
         bool m_JobsGenerated {false};
         QJsonObject m_PresetSettings, m_FileSettings;
-        QString m_DefectMapFilename, m_MasterDarkFrameFilename;
-        QStringList m_DarkCameras, m_DefectCameras;
+        QString m_DefectMapFilename, m_MasterDarkFrameFilename;        
         QSharedPointer<DarkView> m_DarkView;
         QPointer<QStatusBar> m_StatusBar;
         QPointer<QLabel> m_StatusLabel, m_FileLabel;
@@ -254,6 +299,10 @@ class DarkLibrary : public QDialog, public Ui::DarkLibrary
         QSharedPointer<FITSData> m_CurrentDarkFrame;
         QFutureWatcher<bool> m_DarkFrameFutureWatcher;
 
+        // Settings
+        QVariantMap m_Settings;
+        QVariantMap m_GlobalSettings;
+
         // Do not add to cache if system memory falls below 250MB.
         static constexpr uint16_t CACHE_MEMORY_LIMIT {250};
 };
