@@ -174,7 +174,7 @@ OpticalTrainManager::OpticalTrainManager() : QDialog(KStars::Instance())
             selectOpticalTrain(trainNamesList->currentItem());
     });
 
-    m_CheckMissingDevicesTimer.setInterval(2000);
+    m_CheckMissingDevicesTimer.setInterval(5000);
     m_CheckMissingDevicesTimer.setSingleShot(true);
     connect(&m_CheckMissingDevicesTimer, &QTimer::timeout, this, &OpticalTrainManager::checkMissingDevices);
     initModel();
@@ -583,7 +583,7 @@ bool OpticalTrainManager::selectOpticalTrain(const QString &name)
             filterComboBox->setCurrentText(oneTrain["filterwheel"].toString());
             cameraComboBox->setCurrentText(oneTrain["camera"].toString());
             guiderComboBox->setCurrentText(oneTrain["guider"].toString());
-            removeB->setEnabled(true);
+            removeB->setEnabled(m_OpticalTrains.length() > 1);
             trainConfigBox->setEnabled(true);
             m_Persistent = true;
             return true;
@@ -832,6 +832,20 @@ const QVariantMap OpticalTrainManager::getOpticalTrain(uint8_t id) const
     return QVariantMap();
 }
 
+////////////////////////////////////////////////////////////////////////////
+///
+////////////////////////////////////////////////////////////////////////////
+bool OpticalTrainManager::exists(uint8_t id) const
+{
+    for (auto &oneTrain : m_OpticalTrains)
+    {
+        if (oneTrain["id"].toInt() == id)
+            return true;
+    }
+
+    return false;
+}
+
 ////////////////////////////////////////////////////////////////////////////
 ///
 ////////////////////////////////////////////////////////////////////////////
@@ -977,7 +991,7 @@ void Ekos::OpticalTrainManager::updateOpticalTrainValue(QComboBox *cb, const QSt
 void OpticalTrainManager::updateOpticalTrainValue(double value, const QString &element)
 {
     if (trainNamesList->currentItem() != nullptr && m_Persistent == true)
-        setOpticalTrainValue(trainNamesList->currentItem()->text(), element, QString("%0.2d").arg(value));
+        setOpticalTrainValue(trainNamesList->currentItem()->text(), element, value);
 
 }
 
