@@ -369,12 +369,12 @@ bool SerialPortAssistant::addRule(const QJsonObject &rule)
     if (INDI::WebManager::getWebManagerResponse(QNetworkAccessManager::PostOperation, url, nullptr, &data))
     {
         KSNotification::event(QLatin1String("IndiServerMessage"), i18n("Mapping is successful."));
-        auto devicePort = m_CurrentDevice->getBaseDevice()->getText("DEVICE_PORT");
+        auto devicePort = m_CurrentDevice->getBaseDevice().getText("DEVICE_PORT");
         if (devicePort)
         {
             // Set port in device and then save config
             devicePort->at(0)->setText(QString("/dev/%1").arg(rule["symlink"].toString()).toLatin1().constData());
-            m_CurrentDevice->sendNewText(devicePort);
+            m_CurrentDevice->sendNewProperty(devicePort);
             m_CurrentDevice->setConfig(SAVE_CONFIG);
             m_CurrentDevice->Connect();
         }
