@@ -108,8 +108,6 @@ class Capture : public QWidget, public Ui::Capture
             REMOTE_PREVIEW
         } FilenamePreviewType;
 
-        typedef IPState (Capture::*PauseFunctionPointer)();
-
         Capture();
         ~Capture();
 
@@ -731,6 +729,12 @@ class Capture : public QWidget, public Ui::Capture
         // ////////////////////////////////////////////////////////////////////
         // slots handling device and module events
         // ////////////////////////////////////////////////////////////////////
+
+        /**
+         * @brief captureStarted Manage the result when capturing has been started
+         */
+        void captureStarted(CAPTUREResult rc);
+
         /**
              * @brief setGuideDeviation Set the guiding deviation as measured by the guiding module. Abort capture
              *        if deviation exceeds user value. Resume capture if capture was aborted and guiding
@@ -769,6 +773,9 @@ class Capture : public QWidget, public Ui::Capture
             m_captureModuleState->getRefocusState()->setFocusHFR(newHFR);
         }
 
+        // Filter
+        void setFilterStatus(FilterState filterState);
+
         // Guide
         void setGuideStatus(GuideState state);
 
@@ -779,8 +786,8 @@ class Capture : public QWidget, public Ui::Capture
         // Update Mount module status
         void setMountStatus(ISD::Mount::Status newState);
 
-        // Meridian flip
-        void meridianFlipStatusChanged(MeridianFlipState::MeridianFlipMountState status);
+        // Meridian flip interface
+        void updateMFMountState(MeridianFlipState::MeridianFlipMountState status);
 
         // ////////////////////////////////////////////////////////////////////
         // Module logging
@@ -789,7 +796,7 @@ class Capture : public QWidget, public Ui::Capture
         void appendLogText(const QString &);
 
 
-    private slots:
+private slots:
 
         // ////////////////////////////////////////////////////////////////////
         // UI controls
@@ -867,7 +874,7 @@ class Capture : public QWidget, public Ui::Capture
         Q_SCRIPTABLE void newStatus(CaptureState status);
         Q_SCRIPTABLE void captureComplete(const QVariantMap &metadata);
 
-        void newFilterManagerStatus(FilterState state);
+        void newFilterStatus(FilterState state);
 
         void ready();
 
@@ -889,7 +896,6 @@ class Capture : public QWidget, public Ui::Capture
         void sequenceChanged(const QJsonArray &sequence);
         void settingsUpdated(const QJsonObject &settings);
         void newLocalPreview(const QString &preview);
-        void newMeridianFlipSetup(bool activate, double hours);
         void dslrInfoRequested(const QString &cameraName);
         void driverTimedout(const QString &deviceName);
 
@@ -1082,11 +1088,8 @@ class Capture : public QWidget, public Ui::Capture
 
         double setCurrentADU(double value);
 
-        // Execute the meridian flip
-        void setMeridianFlipStage(MeridianFlipState::MFStage stage);
-        void processFlipCompleted();
-
-        void processGuidingFailed();
+        // Propagate meridian flip state changes to the UI
+        void updateMeridianFlipStage(MeridianFlipState::MFStage stage);
 
         // ////////////////////////////////////////////////////////////////////
         // helper functions
@@ -1132,11 +1135,6 @@ class Capture : public QWidget, public Ui::Capture
 
         void resetFrameToZero();
 
-        // short cut for all guiding states that indicate guiding is on
-        bool isGuidingOn();
-        // short cut for all guiding states that indicate guiding in state GUIDING
-        bool isActivelyGuiding();
-
         /**
          * @brief generateScriptArguments Generate argument list to pass to capture script
          * @return generates argument list consisting of one argument -metadata followed by JSON-formatted key:value pair:
@@ -1264,7 +1262,6 @@ class Capture : public QWidget, public Ui::Capture
         uint8_t m_DeviceRestartCounter { 0 };
 
         bool useGuideHead { false };
-        bool autoGuideReady { false};
 
         QString m_TargetName;
         QString m_ObserverName;
@@ -1307,8 +1304,6 @@ class Capture : public QWidget, public Ui::Capture
         bool suspendGuideOnDownload { false };
         QJsonArray m_SequenceArray;
 
-        PauseFunctionPointer pauseFunction { nullptr };
-
         // CCD Chip frame settings
         QMap<ISD::CameraChip *, QVariantMap> frameSettings;
 
