@@ -19,6 +19,7 @@
 
 #include "ekos/manager/meridianflipstate.h"
 #include "ekos/capture/refocusstate.h"
+#include "ekos/auxiliary/filtermanager.h"
 
 namespace Ekos
 {
@@ -40,7 +41,8 @@ class CaptureModuleState: public QObject
             ACTION_MOUNT_PARK,          /* Park the mount.                                                                                */
             ACTION_DOME_PARK,           /* Park the dome.                                                                                 */
             ACTION_FLAT_SYNC_FOCUS,     /* Move the focuser to the focus position for the selected filter.                                */
-            ACTION_SCOPE_COVER          /* Ensure that the scope cover (if present) is opened.                                            */
+            ACTION_SCOPE_COVER,         /* Ensure that the scope cover (if present) is opened.                                            */
+            ACTION_AUTOFOCUS            /* Execute autofocus (might be triggered due to filter change).                                   */
         } PrepareActions;
 
         typedef enum
@@ -69,6 +71,13 @@ class CaptureModuleState: public QObject
             CAP_LIGHT_BUSY     /* light state changing      */
         } LightState;
 
+        typedef enum
+        {
+            CONTINUE_ACTION_NONE,            /* do nothing              */
+            CONTINUE_ACTION_NEXT_EXPOSURE,   /* start next exposure     */
+            CONTINUE_ACTION_CAPTURE_COMPLETE /* recall capture complete */
+        } ContinueAction;
+
         CaptureModuleState(QObject *parent = nullptr);
 
         // ////////////////////////////////////////////////////////////////////
@@ -107,8 +116,7 @@ class CaptureModuleState: public QObject
         {
             MANAUL_COVER_OPEN,
             MANUAL_COVER_CLOSED_LIGHT,
-            MANUAL_COVER_CLOSED_DARK,
-
+            MANUAL_COVER_CLOSED_DARK
         } ManualCoverState;
 
         ManualCoverState m_ManualCoverState { MANAUL_COVER_OPEN };
@@ -144,6 +152,15 @@ class CaptureModuleState: public QObject
             m_StartingCapture = newStartingCapture;
         }
 
+        ContinueAction getContinueAction() const
+        {
+            return m_ContinueAction;
+        }
+        void setContinueAction(ContinueAction newPauseFunction)
+        {
+            m_ContinueAction = newPauseFunction;
+        }
+
         FocusState getFocusState() const
         {
             return m_FocusState;
@@ -157,10 +174,12 @@ class CaptureModuleState: public QObject
         {
             return m_GuideState;
         }
-        void setGuideState(GuideState value)
-        {
-            m_GuideState = value;
-        }
+        void setGuideState(GuideState state);
+
+        // short cut for all guiding states that indicate guiding is on
+        bool isGuidingOn();
+        // short cut for all guiding states that indicate guiding in state GUIDING
+        bool isActivelyGuiding();
 
         QTimer &getCaptureDelayTimer()
         {
@@ -207,10 +226,7 @@ class CaptureModuleState: public QObject
         {
             return m_AlignState;
         }
-        void setAlignState(AlignState value)
-        {
-            m_AlignState = value;
-        }
+        void setAlignState(AlignState value);
 
         FilterState getFilterManagerState() const
         {
@@ -349,19 +365,61 @@ class CaptureModuleState: public QObject
         bool checkDithering();
 
         /**
-             * @brief Check whether a meridian flip has been requested and trigger it
-             * @return true iff a meridian flip has been triggered
-             */
+         * @brief updateMFMountState Handle changes of the meridian flip mount state
+         */
+        void updateMFMountState(MeridianFlipState::MeridianFlipMountState status);
+
+        /**
+         * @brief updateMeridianFlipStage Update the meridian flip stage
+         */
+        void updateMeridianFlipStage(const MeridianFlipState::MFStage &stage);
+
+        /**
+         * @brief checkMeridianFlipActive
+         * @return true iff the meridian flip itself or post flip actions are running
+         */
+        bool checkMeridianFlipActive();
+
+        /**
+         * @brief Check whether a meridian flip has been requested and trigger it
+         * @return true iff a meridian flip has been triggered
+         */
         bool checkMeridianFlipReady();
 
         /**
-             * @brief Check if the mount's flip has been completed and start guiding
-             * if necessary. Starting guiding after the meridian flip works through
-             * the signal {@see startGuidingAfterFlip()}
-             * @return true if guiding needs to start but is not running yet
-             */
+         * @brief checkPostMeridianFlipActions Execute the checks necessary after the mount
+         * has completed the meridian flip.
+         * @return true iff the post meridian flip actions are ongoing, false if completed or not necessary
+         */
+        bool checkPostMeridianFlipActions();
+
+        /**
+         * @brief Check if an alignment needs to be executed after completing
+         * a meridian flip.
+         * @return
+         */
+        bool checkAlignmentAfterFlip();
+
+        /**
+         * @brief Check if the mount's flip has been completed and start guiding
+         * if necessary. Starting guiding after the meridian flip works through
+         * the signal {@see startGuidingAfterFlip()}
+         * @return true if guiding needs to start but is not running yet
+         */
         bool checkGuidingAfterFlip();
 
+        /**
+         * @brief processGuidingFailed React when guiding failed.
+         *
+         * If aguiding has been started before and stopped, capturing aborts except
+         * for the case that either
+         *  - a meridian flip is running
+         *  - a job is running for non light frames
+         *  - capturing is either paused or suspended
+         *  In these case, nothing is done.
+         */
+        void processGuidingFailed();
+
         /**
          * @brief Process changes necessary when the focus state changes.
          */
@@ -387,13 +445,6 @@ class CaptureModuleState: public QObject
          */
         void updateHFRThreshold();
 
-        /**
-             * @brief Check if an alignment needs to be executed after completing
-             * a meridian flip.
-             * @return
-             */
-        bool checkAlignmentAfterFlip();
-
         /**
          * @brief Slot that listens to guiding deviations reported by the Guide module.
          *
@@ -419,6 +470,10 @@ signals:
         void startCapture();
         void abortCapture();
         void suspendCapture();
+        // mount meridian flip status update event
+        void newMeridianFlipStage(MeridianFlipState::MFStage status);
+        // meridian flip started
+        void meridianFlipStarted();
         // guiding should be started after a successful meridian flip
         void guideAfterMeridianFlip();
         // new capture state
@@ -434,9 +489,10 @@ signals:
         // new HFR focus limit calculated
         void newLimitFocusHFR(double hfr);
         // Select the filter at the given position
-        void newFilterPosition(int targetFilterPosition);
+        void newFilterPosition(int targetFilterPosition, FilterManager::FilterPolicy policy = FilterManager::ALL_POLICIES);
         // new log text for the module log window
         void newLog(const QString &text);
+
 private:
         // list of all sequence jobs
         QList<SequenceJob *> m_allJobs;
@@ -464,6 +520,8 @@ private:
         // for the first capture job that is ready to be executed.
         // @see Capture::start().
         QTimer m_captureDelayTimer;
+        // how to continue after pausing
+        ContinueAction m_ContinueAction { CONTINUE_ACTION_NONE };
 
 
         // ////////////////////////////////////////////////////////////////////
