@@ -14,6 +14,7 @@
 
 #include <cmath>
 #include <algorithm>
+#include <ekos_capture_debug.h>
 
 namespace Ekos
 {
@@ -57,12 +58,10 @@ QString PlaceholderPath::defaultFormat(bool useFilter, bool useExposure, bool us
 
 void PlaceholderPath::processJobInfo(SequenceJob *job, const QString &targetName)
 {
-    job->setCoreProperty(SequenceJob::SJ_TargetName, targetName);
-
+    QString jobTargetName = targetName;
     auto frameType = getFrameType(job->getFrameType());
     auto filterType = job->getCoreProperty(SequenceJob::SJ_Filter).toString();
     auto exposure    = job->getCoreProperty(SequenceJob::SJ_Exposure).toDouble();
-    auto jobTargetName = job->getCoreProperty(SequenceJob::SJ_TargetName).toString();
     auto filterEnabled = job->getCoreProperty(SequenceJob::SJ_FilterPrefixEnabled).toBool();
     auto expEnabled = job->getCoreProperty(SequenceJob::SJ_ExpPrefixEnabled).toBool();
     const auto isDarkFlat = job->getCoreProperty(SequenceJob::SJ_DarkFlat).toBool();
@@ -153,19 +152,15 @@ void PlaceholderPath::processJobInfo(SequenceJob *job, const QString &targetName
         job->setCoreProperty(SequenceJob::SJ_UsingPlaceholders, true);
     }
 
-    QString signature = generateFilename(*job, job->getCoreProperty(SequenceJob::SJ_TargetName).toString(), true, true,
-                                         1, ".fits", "", false, true);
+    QString signature = generateFilename(*job, jobTargetName, true, true, 1, ".fits", "", false, true);
     job->setCoreProperty(SequenceJob::SJ_Signature, signature);
 }
 
 void PlaceholderPath::addJob(SequenceJob *job, const QString &targetName)
 {
-    job->setCoreProperty(SequenceJob::SJ_TargetName, targetName);
-
     auto frameType = job->getFrameType();
     auto frameTypeString = getFrameType(job->getFrameType());
-    const auto jobTargetName = job->getCoreProperty(SequenceJob::SJ_TargetName).toString();
-    QString imagePrefix = jobTargetName;
+    QString imagePrefix = targetName;
 
     const auto isDarkFlat = job->getCoreProperty(SequenceJob::SJ_DarkFlat).toBool();
     if (isDarkFlat)
@@ -284,8 +279,8 @@ QString PlaceholderPath::generateFilename(const SequenceJob &job,
 QString PlaceholderPath::generateFilename(const bool batch_mode, const int nextSequenceID, const QString &extension,
         const QString &filename, const bool glob, const bool gettingSignature) const
 {
-    return generateFilename(m_Directory, m_format, m_formatSuffix, m_targetName, m_DarkFlat, m_filter, m_frameType, m_exposure,
-                            batch_mode, nextSequenceID, extension, filename, glob, gettingSignature);
+    return generateFilename(m_Directory, m_format, m_formatSuffix, m_targetName, m_DarkFlat, m_filter, m_frameType,
+                            m_exposure, batch_mode, nextSequenceID, extension, filename, glob, gettingSignature);
 }
 
 QString PlaceholderPath::generateFilename(const QString &directory,
@@ -304,7 +299,7 @@ QString PlaceholderPath::generateFilename(const QString &directory,
         const bool gettingSignature) const
 {
     QString targetNameSanitized = targetName;
-    targetNameSanitized.replace( QRegularExpression("\\s|/|\\(|\\)|:|\\*|~|\"" ), "_" )
+    targetNameSanitized.replace( QRegularExpression("\\s|/|\\(|\\)|:|\\*|\\+|~|\"" ), "_" )
     // Remove any two or more __
     .replace( QRegularExpression("_{2,}"), "_")
     // Remove any _ at the end
@@ -316,10 +311,7 @@ QString PlaceholderPath::generateFilename(const QString &directory,
     if (batch_mode)
         currentDir = directory;
     else
-        currentDir = KSPaths::writableLocation(QStandardPaths::TempLocation) + QDir::separator() + "kstars/";
-
-    //    if (currentDir.endsWith(QDir::separator()) == false)
-    //        currentDir += QDir::separator();
+        currentDir = QDir::toNativeSeparators(KSPaths::writableLocation(QStandardPaths::TempLocation) + "/kstars/");
 
     QString tempFormat = currentDir + format + "_%s" + QString::number(formatSuffix);
 
@@ -327,7 +319,12 @@ QString PlaceholderPath::generateFilename(const QString &directory,
     QRegularExpression
     // This is the original regex with %p & %d tags - disabled for now to simply
     // re("(?<replace>\\%(?<name>(filename|f|Datetime|D|Type|T|exposure|e|Filter|F|target|t|sequence|s|directory|d|path|p))(?<level>\\d+)?)(?<sep>[_/])?");
+#if defined(Q_OS_WIN)
+    re("(?<replace>\\%(?<name>(filename|f|Datetime|D|Type|T|exposure|e|Filter|F|target|t|sequence|s))(?<level>\\d+)?)(?<sep>[_\\\\])?");
+#else
     re("(?<replace>\\%(?<name>(filename|f|Datetime|D|Type|T|exposure|e|Filter|F|target|t|sequence|s))(?<level>\\d+)?)(?<sep>[_/])?");
+#endif
+
     while ((i = tempFormat.indexOf(re, i, &match)) != -1)
     {
         QString replacement = "";
@@ -411,6 +408,7 @@ QString PlaceholderPath::generateFilename(const QString &directory,
         }
         else
             qWarning() << "Unknown replacement string: " << match.captured("replace");
+
         if (replacement.isEmpty())
             tempFormat = tempFormat.replace(match.capturedStart(), match.capturedLength(), replacement);
         else
@@ -426,14 +424,14 @@ QString PlaceholderPath::generateFilename(const QString &directory,
     return tempFilename;
 }
 
-void PlaceholderPath::setGenerateFilenameSettings(const SequenceJob &job)
+void PlaceholderPath::setGenerateFilenameSettings(const SequenceJob &job, const QString &targetName)
 {
+    m_targetName          = targetName;
     m_frameType           = job.getFrameType();
     m_filterPrefixEnabled = job.getCoreProperty(SequenceJob::SJ_FilterPrefixEnabled).toBool();
     m_expPrefixEnabled    = job.getCoreProperty(SequenceJob::SJ_ExpPrefixEnabled).toBool();
     m_filter              = job.getCoreProperty(SequenceJob::SJ_Filter).toString();
     m_exposure            = job.getCoreProperty(SequenceJob::SJ_Exposure).toDouble();
-    m_targetName          = job.getCoreProperty(SequenceJob::SJ_TargetName).toString();
     m_Directory           = job.getCoreProperty(SequenceJob::SJ_LocalDirectory).toString();
     m_format              = job.getCoreProperty(SequenceJob::SJ_PlaceholderFormat).toString();
     m_formatSuffix        = job.getCoreProperty(SequenceJob::SJ_PlaceholderSuffix).toUInt();
@@ -445,7 +443,11 @@ QStringList PlaceholderPath::remainingPlaceholders(const QString &filename)
 {
     QList<QString> placeholders = {};
     QRegularExpressionMatch match;
-    QRegularExpression re("(?<replace>\\%(?<name>[a-z])(?<level>\\d+)?)(?<sep>[_/])?");
+#if defined(Q_OS_WIN)
+    QRegularExpression re("(?<replace>\\%(?<name>[a-zA-Z])(?<level>\\d+)?)(?<sep>[_\\\\])+");
+#else
+    QRegularExpression re("(?<replace>%(?<name>[a-zA-Z])(?<level>\\d+)?)(?<sep>[_/])+");
+#endif
     int i = 0;
     while ((i = filename.indexOf(re, i, &match)) != -1)
     {
@@ -459,13 +461,30 @@ QStringList PlaceholderPath::remainingPlaceholders(const QString &filename)
 QList<int> PlaceholderPath::getCompletedFileIds(const SequenceJob &job, const QString &targetName)
 {
     QString path = generateFilename(job, targetName, true, true, 0, ".*", "", true);
-    QFileInfo path_info(path);
+    auto sanitizedPath = path;
+
+    // This is needed for Windows as the regular expression confuses path search
+    QString idRE = "(?<id>\\d+).*";
+    QString datetimeRE = "\\d\\d\\d\\d-\\d\\d-\\d\\dT\\d\\d-\\d\\d-\\d\\d";
+    sanitizedPath.replace(idRE, "{IDRE}");
+    sanitizedPath.replace(datetimeRE, "{DATETIMERE}");
+
+    // Now we can get a proper directory
+    QFileInfo path_info(sanitizedPath);
     QDir dir(path_info.dir());
+
+    // e.g. Light_R_(?<id>\\d+).*
+    auto filename = path_info.fileName();
+
+    // Next replace back the problematic regular expressions
+    filename.replace("{IDRE}", idRE);
+    filename.replace("{DATETIMERE}", datetimeRE);
+
     QStringList matchingFiles = dir.entryList(QDir::Files);
     QRegularExpressionMatch match;
-    QRegularExpression re("^" + path_info.fileName() + "$");
+    QRegularExpression re("^" + filename + "$");
     QList<int> ids = {};
-    for (auto name : matchingFiles)
+    for (auto &name : matchingFiles)
     {
         match = re.match(name);
         if (match.hasMatch())
@@ -489,5 +508,34 @@ int PlaceholderPath::checkSeqBoundary(const SequenceJob &job, const QString &tar
         return 1;
 }
 
+// An "emergency" method--the code should not be overwriting files,
+// however, if we've detected an overwrite, we generate a new filename
+// by looking for numbers at its end (before its extension) and incrementing
+// that number, checking to make sure the new filename with the incremented number doesn't exist.
+QString PlaceholderPath::repairFilename(const QString &filename)
+{
+    QRegularExpression re("^(.*[^\\d])(\\d+)\\.(\\w+)$");
+
+    auto match = re.match(filename);
+    if (match.hasMatch())
+    {
+        QString prefix = match.captured(1);
+        int number = match.captured(2).toInt();
+        int numberLength = match.captured(2).size();
+        QString extension = match.captured(3);
+        QString candidate = QString("%1%2.%3").arg(prefix).arg(number + 1, numberLength, 10, QLatin1Char('0')).arg(extension);
+        int maxIterations = 2000;
+        while (QFile::exists(candidate))
+        {
+            number = number + 1;
+            candidate = QString("%1%2.%3").arg(prefix).arg(number, numberLength, 10, QLatin1Char('0')).arg(extension);
+            if (--maxIterations <= 0)
+                return filename;
+        }
+        return candidate;
+    }
+    return filename;;
+}
+
 }
 
