@@ -8,13 +8,11 @@
 
 #include "cloud.h"
 #include "commands.h"
-#include "profileinfo.h"
-
-#include "fitsviewer/fitsview.h"
 #include "fitsviewer/fitsdata.h"
-#include "fitsviewer/fpack.h"
 
 #include "ekos_debug.h"
+#include "version.h"
+#include "../fitsviewer/fpack.h"
 
 #include <QtConcurrent>
 #include <QFutureWatcher>
@@ -32,8 +30,9 @@ Cloud::Cloud(Ekos::Manager * manager): m_Manager(manager)
 
     connect(&watcher, &QFutureWatcher<bool>::finished, this, &Cloud::sendImage, Qt::UniqueConnection);
 
-    connect(this, &Cloud::newMetadata, this, &Cloud::uploadMetadata);
     connect(this, &Cloud::newImage, this, &Cloud::uploadImage);
+
+    connect(Options::self(), &Options::EkosLiveCloudChanged, this, &Cloud::updateOptions);
 }
 
 void Cloud::connectServer()
@@ -45,13 +44,13 @@ void Cloud::connectServer()
     query.addQueryItem("token", m_AuthResponse["token"].toString());
     if (m_AuthResponse.contains("remoteToken"))
         query.addQueryItem("remoteToken", m_AuthResponse["remoteToken"].toString());
-    if (m_Options[OPTION_SET_CLOUD_STORAGE])
-        query.addQueryItem("cloudEnabled", "true");
+    query.addQueryItem("cloudEnabled", Options::ekosLiveCloud() ? "true" : "false");
     query.addQueryItem("email", m_AuthResponse["email"].toString());
     query.addQueryItem("from_date", m_AuthResponse["from_date"].toString());
     query.addQueryItem("to_date", m_AuthResponse["to_date"].toString());
     query.addQueryItem("plan_id", m_AuthResponse["plan_id"].toString());
     query.addQueryItem("type", m_AuthResponse["type"].toString());
+    query.addQueryItem("version", KSTARS_VERSION);
 
     requestURL.setPath("/cloud/ekos");
     requestURL.setQuery(query);
@@ -130,7 +129,7 @@ void Cloud::onTextReceived(const QString &message)
 
 void Cloud::upload(const QSharedPointer<FITSData> &data, const QString &uuid)
 {
-    if (m_isConnected == false || m_Options[OPTION_SET_CLOUD_STORAGE] == false  || m_sendBlobs == false)
+    if (m_isConnected == false || Options::ekosLiveCloud() == false  || m_sendBlobs == false)
         return;
 
     m_UUID = uuid;
@@ -140,7 +139,7 @@ void Cloud::upload(const QSharedPointer<FITSData> &data, const QString &uuid)
 
 void Cloud::upload(const QString &filename, const QString &uuid)
 {
-    if (m_isConnected == false || m_Options[OPTION_SET_CLOUD_STORAGE] == false  || m_sendBlobs == false)
+    if (m_isConnected == false || Options::ekosLiveCloud() == false  || m_sendBlobs == false)
         return;
 
     watcher.waitForFinished();
@@ -169,7 +168,7 @@ void Cloud::asyncUpload()
     }
 
     // Filename only without path
-    QString filepath = m_ImageData->isCompressed() ? m_ImageData->compressedFilename() : m_ImageData->filename();
+    QString filepath = m_ImageData->filename();
     QString filenameOnly = QFileInfo(filepath).fileName();
 
     // Add filename and size as wells
@@ -177,33 +176,23 @@ void Cloud::asyncUpload()
     metadata.insert("filename", filenameOnly);
     metadata.insert("filesize", static_cast<int>(m_ImageData->size()));
     // Must set Content-Disposition so
-    if (m_ImageData->isCompressed())
-        metadata.insert("Content-Disposition", QString("attachment;filename=%1").arg(filenameOnly));
-    else
-        metadata.insert("Content-Disposition", QString("attachment;filename=%1.fz").arg(filenameOnly));
+    metadata.insert("Content-Disposition", QString("attachment;filename=%1.fz").arg(filenameOnly));
 
-    emit newMetadata(QJsonDocument(metadata).toJson(QJsonDocument::Compact));
-    //m_WebSocket.sendTextMessage(QJsonDocument(metadata).toJson(QJsonDocument::Compact));
-
-    qCInfo(KSTARS_EKOS) << "Uploading file to the cloud with metadata" << metadata;
-
-    QString compressedFile = filepath;
-    // Use cfitsio pack to compress the file first
-    if (m_ImageData->isCompressed() == false)
-    {
-        compressedFile = QDir::tempPath() + QString("/ekoslivecloud%1").arg(m_UUID);
-        m_ImageData->saveImage(compressedFile + QStringLiteral("[compress R]"));
-    }
+    QByteArray image;
+    QByteArray meta = QJsonDocument(metadata).toJson(QJsonDocument::Compact);
+    meta = meta.leftJustified(METADATA_PACKET, 0);
+    image += meta;
 
+    QString compressedFile = QDir::tempPath() + QString("/ekoslivecloud%1").arg(m_UUID);
+    m_ImageData->saveImage(compressedFile + QStringLiteral("[compress R]"));
     // Upload the compressed image
-    QFile image(compressedFile);
-    if (image.open(QIODevice::ReadOnly))
+    QFile compressedImage(compressedFile);
+    if (compressedImage.open(QIODevice::ReadOnly))
     {
-        //m_WebSocket.sendBinaryMessage(image.readAll());
-        emit newImage(image.readAll());
+        image += compressedImage.readAll();
+        emit newImage(image);
         qCInfo(KSTARS_EKOS) << "Uploaded" << compressedFile << " to the cloud";
     }
-    image.close();
 
     // Remove from disk if temporary
     if (compressedFile != filepath && compressedFile.startsWith(QDir::tempPath()))
@@ -212,30 +201,21 @@ void Cloud::asyncUpload()
     m_ImageData.reset();
 }
 
-void Cloud::uploadMetadata(const QByteArray &metadata)
-{
-    m_WebSocket.sendTextMessage(metadata);
-}
-
 void Cloud::uploadImage(const QByteArray &image)
 {
     m_WebSocket.sendBinaryMessage(image);
 }
 
-void Cloud::setOptions(QMap<int, bool> options)
+void Cloud::updateOptions()
 {
-    bool cloudEnabled = m_Options[OPTION_SET_CLOUD_STORAGE];
-    m_Options = options;
-
     // In case cloud storage is toggled, inform cloud
     // websocket channel of this change.
-    if (cloudEnabled != m_Options[OPTION_SET_CLOUD_STORAGE])
+    if (m_isConnected)
     {
-        bool enabled = m_Options[OPTION_SET_CLOUD_STORAGE];
-        QJsonObject payload = {{"value", enabled}};
+        QJsonObject payload = {{"name", "ekosLiveCloud"}, {"value", Options::ekosLiveCloud()}};
         QJsonObject message =
         {
-            {"type",  commands[OPTION_SET_CLOUD_STORAGE]},
+            {"type",  commands[OPTION_SET]},
             {"payload", payload}
         };
 
