@@ -11,7 +11,6 @@
 #include <QtWebSockets/QWebSocket>
 #include <memory>
 
-#include "ekos/ekos.h"
 #include "ekos/manager.h"
 
 class FITSView;
@@ -47,14 +46,12 @@ class Cloud : public QObject
     signals:
         void connected();
         void disconnected();
-
-        void newMetadata(const QByteArray &metadata);
         void newImage(const QByteArray &image);
 
     public slots:
         void connectServer();
         void disconnectServer();
-        void setOptions(QMap<int, bool> options);
+        void updateOptions();
 
     private slots:
         // Connection
@@ -68,8 +65,6 @@ class Cloud : public QObject
         // Send image
         void sendImage();
 
-        // Metadata and Image upload
-        void uploadMetadata(const QByteArray &metadata);
         void uploadImage(const QByteArray &image);
 
     private:
@@ -91,8 +86,6 @@ class Cloud : public QObject
         bool m_isConnected {false};
         bool m_sendBlobs {true};
 
-        QMap<int, bool> m_Options;
-
         // Image width for high-bandwidth setting
         static const uint16_t HB_WIDTH = 640;
         // Image high bandwidth image quality (jpg)
@@ -100,6 +93,9 @@ class Cloud : public QObject
         // Video high bandwidth video quality (jpg)
         static const uint8_t HB_VIDEO_QUALITY = 64;
 
+        // Binary Metadata Size
+        static const uint16_t METADATA_PACKET = 2048;
+
         // Retry every 5 seconds in case remote server is down
         static const uint16_t RECONNECT_INTERVAL = 5000;
         // Retry for 1 hour before giving up
