@@ -7,21 +7,11 @@
 #include "Options.h"
 
 #include "ekosliveclient.h"
-#include "ekos_debug.h"
 #include "ekos/manager.h"
-#include "ekos/capture/capture.h"
-#include "ekos/mount/mount.h"
-#include "ekos/focus/focus.h"
 
 #include "kspaths.h"
-#include "kstarsdata.h"
-#include "filedownloader.h"
 #include "QProgressIndicator.h"
 
-#include "indi/indilistener.h"
-#include "indi/indiccd.h"
-#include "indi/indifilter.h"
-
 #include <config-kstars.h>
 
 #ifdef HAVE_KEYCHAIN
@@ -54,12 +44,12 @@ Client::Client(Ekos::Manager *manager) : QDialog(manager), m_Manager(manager)
     connectionState->setPixmap(QIcon::fromTheme("state-offline").pixmap(QSize(64, 64)));
 
     username->setText(Options::ekosLiveUsername());
-    connect(username, &QLineEdit::editingFinished, [ = ]()
+    connect(username, &QLineEdit::editingFinished, this, [this]()
     {
         Options::setEkosLiveUsername(username->text());
     });
 
-    connect(connectB, &QPushButton::clicked, [ = ]()
+    connect(connectB, &QPushButton::clicked, this, [this]()
     {
         if (m_isConnected)
             disconnectAuthServer();
@@ -67,7 +57,7 @@ Client::Client(Ekos::Manager *manager) : QDialog(manager), m_Manager(manager)
             connectAuthServer();
     });
 
-    connect(password, &QLineEdit::returnPressed, [ = ]()
+    connect(password, &QLineEdit::returnPressed, this, [this]()
     {
         if (!m_isConnected)
             connectAuthServer();
@@ -92,7 +82,7 @@ Client::Client(Ekos::Manager *manager) : QDialog(manager), m_Manager(manager)
     else
         ekosLiveOfflineR->setChecked(true);
 
-    connect(ekosLiveOnlineR, &QRadioButton::toggled, [&](bool toggled)
+    connect(ekosLiveOnlineR, &QRadioButton::toggled, this, [&](bool toggled)
     {
         Options::setEkosLiveOnline(toggled);
         if (toggled)
@@ -124,18 +114,13 @@ Client::Client(Ekos::Manager *manager) : QDialog(manager), m_Manager(manager)
     QKeychain::ReadPasswordJob *job = new QKeychain::ReadPasswordJob(QLatin1String("kstars"));
     job->setAutoDelete(false);
     job->setKey(QLatin1String("ekoslive"));
-    connect(job, &QKeychain::Job::finished, [&](QKeychain::Job * job)
+    connect(job, &QKeychain::Job::finished, this, [&](QKeychain::Job * job)
     {
         if (job->error() == false)
         {
-            //QJsonObject data = QJsonDocument::fromJson(dynamic_cast<QKeychain::ReadPasswordJob*>(job)->textData().toLatin1()).object();
-            //const QString usernameText = data["username"].toString();
-            //const QString passwordText = data["password"].toString();
-
             const auto passwordText = dynamic_cast<QKeychain::ReadPasswordJob*>(job)->textData().toLatin1();
 
             // Only set and attempt connection if the data is not empty
-            //if (usernameText.isEmpty() == false && passwordText.isEmpty() == false)
             if (passwordText.isEmpty() == false && username->text().isEmpty() == false)
             {
                 //username->setText(usernameText);
@@ -155,7 +140,7 @@ Client::Client(Ekos::Manager *manager) : QDialog(manager), m_Manager(manager)
     m_Message->setURL(m_wsURL);
     connect(m_Message, &Message::connected, this, &Client::onConnected);
     connect(m_Message, &Message::disconnected, this, &Client::onDisconnected);
-    connect(m_Message, &Message::expired, [&]()
+    connect(m_Message, &Message::expired, this, [&]()
     {
         // If token expired, disconnect and reconnect again.
         disconnectAuthServer();
@@ -163,11 +148,11 @@ Client::Client(Ekos::Manager *manager) : QDialog(manager), m_Manager(manager)
     });
 
     m_Media = new Media(m_Manager);
-    connect(m_Message, &Message::optionsChanged, m_Media, &Media::setOptions);
+    //connect(m_Message, &Message::optionsUpdated, m_Media, &Media::updateOptions);
     m_Media->setURL(m_wsURL);
 
     m_Cloud = new Cloud(m_Manager);
-    connect(m_Message, &Message::optionsChanged, m_Cloud, &Cloud::setOptions);
+    //connect(m_Message, &Message::optionsUpdated, m_Cloud, &Cloud::updateOptions);
     m_Cloud->setURL(m_wsURL);
 }
 
