@@ -65,12 +65,6 @@ class Media : public QObject
         // Capture
         void sendVideoFrame(const QSharedPointer<QImage> &frame);
 
-        // Options
-        void setOptions(QMap<int, bool> options)
-        {
-            m_Options = options;
-        }
-
         // Correction Vector
         void setCorrectionVector(QLineF correctionVector)
         {
@@ -106,8 +100,6 @@ class Media : public QObject
         QUrl m_URL;
         QString m_UUID;
 
-        QMap<int, bool> m_Options;
-
         QString extension;
         QStringList temporaryFiles;
         QLineF correctionVector;
