@@ -20,13 +20,13 @@
 #include "kstars.h"
 #include "kstarsdata.h"
 #include "ekos_debug.h"
-#include "fitsviewer/fitsview.h"
 #include "ksalmanac.h"
 #include "skymapcomposite.h"
 #include "catalogobject.h"
 #include "ekos/auxiliary/darklibrary.h"
 #include "skymap.h"
 #include "Options.h"
+#include "version.h"
 
 #include <KActionCollection>
 #include <basedevice.h>
@@ -60,6 +60,7 @@ void Message::connectServer()
     query.addQueryItem("to_date", m_AuthResponse["to_date"].toString());
     query.addQueryItem("plan_id", m_AuthResponse["plan_id"].toString());
     query.addQueryItem("type", m_AuthResponse["type"].toString());
+    query.addQueryItem("version", KSTARS_VERSION);
 
     requestURL.setPath("/message/ekos");
     requestURL.setQuery(query);
@@ -1261,7 +1262,9 @@ void Message::processOptionsCommands(const QString &command, const QJsonObject &
         const QJsonArray options = payload["options"].toArray();
         for (const auto &oneOption : options)
             Options::self()->setProperty(oneOption["name"].toString().toLatin1(), oneOption["value"].toVariant());
-        return;
+
+        Options::self()->save();
+        emit optionsUpdated();
     }
     else if (command == commands[OPTION_GET])
     {
@@ -1277,18 +1280,7 @@ void Message::processOptionsCommands(const QString &command, const QJsonObject &
             result.append(QJsonObject::fromVariantMap(map));
         }
         sendResponse(commands[OPTION_GET], result);
-        return;
     }
-    if (command == commands[OPTION_SET_HIGH_BANDWIDTH])
-        m_Options[OPTION_SET_HIGH_BANDWIDTH] = payload["value"].toBool(true);
-    else if (command == commands[OPTION_SET_IMAGE_TRANSFER])
-        m_Options[OPTION_SET_IMAGE_TRANSFER] = payload["value"].toBool(true);
-    else if (command == commands[OPTION_SET_NOTIFICATIONS])
-        m_Options[OPTION_SET_NOTIFICATIONS] = payload["value"].toBool(true);
-    else if (command == commands[OPTION_SET_CLOUD_STORAGE])
-        m_Options[OPTION_SET_CLOUD_STORAGE] = payload["value"].toBool(false);
-
-    emit optionsChanged(m_Options);
 }
 
 ///////////////////////////////////////////////////////////////////////////////////////////
@@ -2336,7 +2328,7 @@ void Message::sendStates()
 ///////////////////////////////////////////////////////////////////////////////////////////
 void Message::sendEvent(const QString &message, KSNotification::EventSource source, KSNotification::EventType event)
 {
-    if (m_isConnected == false || m_Options[OPTION_SET_NOTIFICATIONS] == false)
+    if (m_isConnected == false || Options::ekosLiveNotifications() == false)
         return;
 
     QJsonObject newEvent =
