@@ -75,7 +75,8 @@ void InternalGuider::setTimer(std::unique_ptr<QTimer> &timer, Seconds seconds)
 
 void InternalGuider::setDarkGuideTimerInterval()
 {
-    const Seconds seconds(Options::gPGDarkGuidingInterval());
+    constexpr double kMinInterval = 0.5;  // 0.5s is the shortest allowed dark-guiding period.
+    const Seconds seconds(std::max(kMinInterval, Options::gPGDarkGuidingInterval()));
     setTimer(m_darkGuideTimer, seconds);
 }
 
@@ -289,8 +290,7 @@ bool InternalGuider::dither(double pixels)
     {
         // If the star position is lost, just lose this iteration.
         // If it happens too many time, abort.
-        constexpr int abortStarLostThreshold = MAX_LOST_STAR_THRESHOLD * 3;
-        if (++m_starLostCounter > abortStarLostThreshold)
+        if (++m_starLostCounter > MAX_LOST_STAR_THRESHOLD)
         {
             qCDebug(KSTARS_EKOS_GUIDE) << "Too many consecutive lost stars." << m_starLostCounter << "Aborting dither.";
             return abortDither();
@@ -324,10 +324,25 @@ bool InternalGuider::dither(double pixels)
         double totalXOffset = ret_x - m_DitherOrigin.x();
         double totalYOffset = ret_y - m_DitherOrigin.y();
 
-        if (fabs(diff_x + totalXOffset) > MAX_DITHER_TRAVEL)
+        // if we've dithered too far, and diff_x or diff_y is pushing us even further away, then change its direction.
+        // Note: it is possible that we've dithered too far, but diff_x/y is pointing in the right direction.
+        // Don't change it in that 2nd case.
+        if (((diff_x + totalXOffset > MAX_DITHER_TRAVEL) && (diff_x > 0)) ||
+                ((diff_x + totalXOffset < -MAX_DITHER_TRAVEL) && (diff_x < 0)))
+        {
+            qCDebug(KSTARS_EKOS_GUIDE)
+                    << QString("Dithering target off by too much in X (abs(%1 + %2) > %3), adjust diff_x from %4 to %5")
+                    .arg(diff_x).arg(totalXOffset).arg(MAX_DITHER_TRAVEL).arg(diff_x).arg(diff_x * -1.5);
             diff_x *= -1.5;
-        if (fabs(diff_y + totalYOffset) > MAX_DITHER_TRAVEL)
+        }
+        if (((diff_y + totalYOffset > MAX_DITHER_TRAVEL) && (diff_y > 0)) ||
+                ((diff_y + totalYOffset < -MAX_DITHER_TRAVEL) && (diff_y < 0)))
+        {
+            qCDebug(KSTARS_EKOS_GUIDE)
+                    << QString("Dithering target off by too much in Y (abs(%1 + %2) > %3), adjust diff_y from %4 to %5")
+                    .arg(diff_y).arg(totalYOffset).arg(MAX_DITHER_TRAVEL).arg(diff_y).arg(diff_y * -1.5);
             diff_y *= -1.5;
+        }
 
         m_DitherTargetPosition = GuiderUtils::Vector(ret_x, ret_y, 0) + GuiderUtils::Vector(diff_x, diff_y, 0);
 
@@ -847,6 +862,9 @@ bool InternalGuider::processGuiding()
             emit guideInfo(info);
         }
 
+        // Restart the dark-guiding timer, so we get the full interval on its 1st timeout.
+        if (this->m_darkGuideTimer->isActive())
+            this->m_darkGuideTimer->start();
     }
 
     if (state == GUIDE_SUSPENDED)
@@ -942,20 +960,20 @@ std::pair<Seconds, Seconds> InternalGuider::calculateGPGTimeStep()
 
 void InternalGuider::darkGuide()
 {
+    // Only dark guide when guiding--e.g. don't dark guide if dithering.
+    if (state != GUIDE_GUIDING)
+        return;
+
     if(Options::gPGDarkGuiding() && isInferencePeriodFinished())
     {
-        qCDebug(KSTARS_EKOS_GUIDE) << "##########BEGIN DARK GUIDING############";
         const cproc_out_params *out;
         auto const timeStep = calculateGPGTimeStep();
         pmath->performDarkGuiding(state, timeStep);
 
         out = pmath->getOutputParameters();
-
-        emit newMultiPulse(out->pulse_dir[GUIDE_RA], out->pulse_length[GUIDE_RA],
-                           out->pulse_dir[GUIDE_DEC], out->pulse_length[GUIDE_DEC], DontCaptureAfterPulses);
+        emit newSinglePulse(out->pulse_dir[GUIDE_RA], out->pulse_length[GUIDE_RA], DontCaptureAfterPulses);
 
         emitAxisPulse(out);
-        qCDebug(KSTARS_EKOS_GUIDE) << "##########END DARK GUIDING############";
     }
 }
 
