@@ -249,7 +249,10 @@ bool Mount::setMount(ISD::Mount *device)
     }
 
     if (m_Mount)
-        m_Mount->disconnect(this);
+    {
+        m_Mount->disconnect(m_Mount, nullptr, this, nullptr);
+        m_Mount->disconnect(m_Mount, nullptr, mf_state.get(), nullptr);
+    }
 
     m_Mount = device;
 
@@ -1659,13 +1662,21 @@ void Mount::refreshOpticalTrain()
     opticalTrainCombo->blockSignals(true);
     opticalTrainCombo->clear();
     opticalTrainCombo->addItems(OpticalTrainManager::Instance()->getTrainNames());
-    trainB->setEnabled(opticalTrainCombo->count() > 0);
+    trainB->setEnabled(true);
 
     QVariant trainID = ProfileSettings::Instance()->getOneSetting(ProfileSettings::MountOpticalTrain);
 
     if (trainID.isValid())
     {
         auto id = trainID.toUInt();
+
+        // If train not found, select the first one available.
+        if (OpticalTrainManager::Instance()->exists(id) == false)
+        {
+            id = OpticalTrainManager::Instance()->id(opticalTrainCombo->itemText(0));
+            ProfileSettings::Instance()->setOneSetting(ProfileSettings::MountOpticalTrain, id);
+        }
+
         auto name = OpticalTrainManager::Instance()->name(id);
 
         opticalTrainCombo->setCurrentText(name);
