@@ -80,13 +80,15 @@ class FITSData : public QObject
         explicit FITSData(const QSharedPointer<FITSData> &other);
         ~FITSData() override;
 
-        /** Structure to hold FITS Header records */
-        typedef struct
+        /** Object to hold FITS Header records */
+        struct Record
         {
+            Record() = default;
+            Record(QString k, QString v, QString c) : key(k), value(v), comment(c) {}
             QString key;      /** FITS Header Key */
             QVariant value;   /** FITS Header Value */
             QString comment;  /** FITS Header Comment, if any */
-        } Record;
+        };
 
         typedef enum
         {
@@ -582,6 +584,10 @@ class FITSData : public QObject
         bool loadCanonicalImage(const QByteArray &buffer, const QString &extension);
         // Load FITS images.
         bool loadFITSImage(const QByteArray &buffer, const QString &extension, const bool isCompressed = false);
+        // Load XISF images.
+        bool loadXISFImage(const QByteArray &buffer);
+        // Save XISF images.
+        bool saveXISFImage(const QString &newFilename);
         // Load RAW images.
         bool loadRAWImage(const QByteArray &buffer, const QString &extension);
 
