@@ -57,7 +57,7 @@ class FITSTab : public QWidget
 
         void clearRecentFITS();
         void selectRecentFITS(int i);
-        void loadFile(const QUrl &imageURL, FITSMode mode = FITS_NORMAL, FITSScale filter = FITS_NONE, bool silent = true);
+        void loadFile(const QUrl &imageURL, FITSMode mode = FITS_NORMAL, FITSScale filter = FITS_NONE);
         bool loadData(const QSharedPointer<FITSData> &data, FITSMode mode = FITS_NORMAL, FITSScale filter = FITS_NONE);
 
         bool saveImage(const QString &filename);
@@ -70,9 +70,9 @@ class FITSTab : public QWidget
         {
             return &currentURL;
         }
-        inline FITSView *getView()
+        inline const QSharedPointer<FITSView> &getView()
         {
-            return m_View.get();
+            return m_View;
         }
         inline QPointer<FITSHistogramEditor> getHistogram()
         {
@@ -89,7 +89,6 @@ class FITSTab : public QWidget
         void loadFITSHeader();
         void headerFITS();
         void histoFITS();
-        void evaluateStats();
         void statFITS();
 
         void setUID(int newID)
@@ -114,7 +113,7 @@ class FITSTab : public QWidget
         void ZoomIn();
         void ZoomOut();
         void ZoomDefault();
-
+        void evaluateStats();
     protected:
         virtual void closeEvent(QCloseEvent *ev) override;
 
@@ -147,7 +146,7 @@ class FITSTab : public QWidget
         QPointer<QListWidget> recentImages;
 
         /// FITS image object
-        std::unique_ptr<FITSView> m_View;
+        QSharedPointer<FITSView> m_View;
 
         /// History for undo/redo
         QUndoStack *undoStack { nullptr };
@@ -172,5 +171,5 @@ class FITSTab : public QWidget
         void newStatus(const QString &msg, FITSBar id);
         void changeStatus(bool clean, const QUrl &imageUrl);
         void loaded();
-        void failed();
+        void failed(const QString &errorMessage);
 };
