@@ -35,7 +35,7 @@
 #include "indi/indigroup.h"
 #include "indi/indiproperty.h"
 #include "indi/indielement.h"
-#include "indi/inditelescope.h"
+#include "indi/indimount.h"
 #include <basedevice.h>
 #endif
 
@@ -596,107 +596,23 @@ void KSPopupMenu::addLinksToMenu(SkyObject *obj, bool showDSS)
         addSeparator();
 }
 
-#if 0
 void KSPopupMenu::addINDI()
 {
 #ifdef HAVE_INDI
-
     if (INDIListener::Instance()->size() == 0)
         return;
 
-    for (auto oneDevice : INDIListener::Instance()->getDevices())
+    for (auto &oneDevice : INDIListener::devices())
     {
-        INDI::BaseDevice *bd = gd->getBaseDevice();
-
-        if (bd == nullptr)
+        if (!(oneDevice->getDriverInterface() & INDI::BaseDevice::TELESCOPE_INTERFACE))
             continue;
 
-        //if (bd->isConnected() == false)
-        //    continue;
 
-        QMenu *menuDevice           = nullptr;
-        ISD::GDInterface *telescope = nullptr;
-
-        foreach (INDI::Property *pp, gd->getProperties())
-        {
-            if (pp->getType() != INDI_SWITCH || INDIListener::Instance()->isStandardProperty(pp->getName()) == false
-                    || QString(pp->getName()).startsWith("TELESCOPE_MOTION"))
-                continue;
-
-            ISwitchVectorProperty *svp = pp->getSwitch();
-
-            for (int i = 0; i < svp->nsp; i++)
-            {
-                if (menuDevice == nullptr)
-                {
-                    menuDevice = new QMenu(gd->getDeviceName());
-                    addMenu(menuDevice);
-                }
-
-                QAction *a = menuDevice->addAction(svp->sp[i].label);
-
-                ISD::GDSetCommand *cmd =
-                    new ISD::GDSetCommand(INDI_SWITCH, pp->getName(), svp->sp[i].name, ISS_ON, this);
-
-                connect(a, &QAction::triggered, gd, [gd, cmd] { gd->setProperty(cmd); });
-
-                if (!strcmp(svp->sp[i].name, "SLEW") || !strcmp(svp->sp[i].name, "SYNC") ||
-                        !strcmp(svp->sp[i].name, "TRACK"))
-                {
-                    telescope = INDIListener::Instance()->getDevice(gd->getDeviceName());
-
-                    if (telescope)
-                    {
-                        connect(a, &QAction::triggered, this, [this, telescope] { telescope->runCommand(INDI_SEND_COORDS); });;
-                    }
-                }
-            }
-
-            if (menuDevice != nullptr)
-                menuDevice->addSeparator();
-        }
-
-        if (telescope != nullptr && menuDevice != nullptr)
-        {
-            if (dynamic_cast<ISD::Telescope*>(telescope)->canCustomPark())
-            {
-                menuDevice->addSeparator();
-                QAction *a = menuDevice->addAction(i18n("Slew && Set As Parking Position"));
-
-                QSignalMapper *scopeMapper = new QSignalMapper(this);
-                scopeMapper->setMapping(a, INDI_CUSTOM_PARKING);
-                connect(a, SIGNAL(triggered()), scopeMapper, SLOT(map()));
-                connect(scopeMapper, SIGNAL(mapped(int)), telescope, SLOT(runCommand(int)));
-            }
-
-            menuDevice->addSeparator();
-
-            QAction *a = menuDevice->addAction(i18n("Center Crosshair"));
-
-            QSignalMapper *scopeMapper = new QSignalMapper(this);
-            scopeMapper->setMapping(a, INDI_FIND_TELESCOPE);
-            connect(a, SIGNAL(triggered()), scopeMapper, SLOT(map()));
-            connect(scopeMapper, SIGNAL(mapped(int)), telescope, SLOT(runCommand(int)));
-        }
-    }
-
-#endif
-}
-#endif
-
-void KSPopupMenu::addINDI()
-{
-#ifdef HAVE_INDI
-    if (INDIListener::Instance()->size() == 0)
-        return;
-
-    for (auto device : INDIListener::Instance()->getDevices())
-    {
-        ISD::Telescope *mount = dynamic_cast<ISD::Telescope *>(device);
+        auto mount = oneDevice->getMount();
         if (!mount)
             continue;
 
-        QMenu *mountMenu = new QMenu(device->getDeviceName());
+        QMenu *mountMenu = new QMenu(mount->getDeviceName());
         mountMenu->setIcon(QIcon::fromTheme("kstars"));
         addMenu(mountMenu);
 
@@ -728,7 +644,7 @@ void KSPopupMenu::addINDI()
             QAction *a =
                 mountMenu->addAction(QIcon::fromTheme("process-stop"), i18n("Abort"));
             a->setEnabled(!mount->isParked());
-            connect(a, &QAction::triggered, [mount] { mount->Abort(); });
+            connect(a, &QAction::triggered, [mount] { mount->abort(); });
             mountMenu->addSeparator();
         }
 
@@ -737,12 +653,12 @@ void KSPopupMenu::addINDI()
             QAction *park =
                 mountMenu->addAction(QIcon::fromTheme("flag-red"), i18n("Park"));
             park->setEnabled(!mount->isParked());
-            connect(park, &QAction::triggered, [mount] { mount->Park(); });
+            connect(park, &QAction::triggered, [mount] { mount->park(); });
 
             QAction *unpark =
                 mountMenu->addAction(QIcon::fromTheme("flag-green"), i18n("UnPark"));
             unpark->setEnabled(mount->isParked());
-            connect(unpark, &QAction::triggered, [mount] { mount->UnPark(); });
+            connect(unpark, &QAction::triggered, [mount] { mount->unpark(); });
 
             mountMenu->addSeparator();
         }
@@ -772,13 +688,13 @@ void KSPopupMenu::addINDI()
                                               i18n("Goto && Set As Parking Position"));
             a->setEnabled(!mount->isParked());
             connect(a, &QAction::triggered,
-                    [mount] { mount->runCommand(INDI_CUSTOM_PARKING); });
+                    [mount] { mount->setCustomParking(); });
         }
 
         QAction *a =
             mountMenu->addAction(QIcon::fromTheme("edit-find"), i18n("Find Telescope"));
         connect(a, &QAction::triggered,
-                [mount] { mount->runCommand(INDI_FIND_TELESCOPE); });
+                [mount] { mount->find(); });
     }
 #endif
 }
