@@ -12,11 +12,7 @@
 #include <QLabel>
 
 #include <QDockWidget>
-#if QT_VERSION >= QT_VERSION_CHECK(5, 8, 0)
 #include <QtDBus/qtdbusglobal.h>
-#else
-#include <QtDBus/qdbusmacros.h>
-#endif
 #ifdef HAVE_CFITSIO
 #include <QPointer>
 #endif
