@@ -1,19 +1,8 @@
-/***************************************************************************
-              solarsystemlistcomponent.cpp  -  K Desktop Planetarium
-                             -------------------
-    begin                : 2005/22/09
-    copyright            : (C) 2005 by Jason Harris
-    email                : kstars@30doradus.org
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2005 Jason Harris <kstars@30doradus.org>
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "solarsystemlistcomponent.h"
 
