@@ -1,19 +1,8 @@
-/***************************************************************************
-                          ksplanetbase.h  -  K Desktop Planetarium
-                             -------------------
-    begin                : Sun Jan 29 2002
-    copyright            : (C) 2002 by Mark Hollomon
-    email                : mhh@mindspring.com
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2002 Mark Hollomon <mhh@mindspring.com>
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #pragma once
 
@@ -123,13 +112,13 @@ class KSPlanetBase : public TrailObject
     const dms &helEcLat() const { return helEcPos.latitude; }
 
     /**
-     * @short Convert Ecliptic logitude/latitude to Right Ascension/Declination.
+     * @short Convert Ecliptic longitude/latitude to Right Ascension/Declination.
      * @param Obliquity current Obliquity of the Ecliptic (angle from Equator)
      */
     void EclipticToEquatorial(const CachingDms *Obliquity);
 
     /**
-     * @short Convert Right Ascension/Declination to Ecliptic logitude/latitude.
+     * @short Convert Right Ascension/Declination to Ecliptic longitude/latitude.
      * @param Obliquity current Obliquity of the Ecliptic (angle from Equator)
      */
     void EquatorialToEcliptic(const CachingDms *Obliquity);
