@@ -16,6 +16,7 @@
 class ConstellationsArt;
 class DeepSkyObject;
 class KSComet;
+class KSAsteroid;
 class KSPlanetBase;
 class KSEarthShadow;
 class LineList;
@@ -110,6 +111,13 @@ class SkyPainter
          */
         virtual bool drawComet(KSComet *com) = 0;
 
+        /**
+         * @short Draw an asteroid in the sky.
+         * @param ast asteroid to draw
+         * @return true if a asteroid was drawn
+         */
+        virtual bool drawAsteroid(KSAsteroid *ast) = 0;
+
         /**
          * @short Draw a point source (e.g., a star).
          * @param loc the location of the source in the sky
